@@ -1,4 +1,4 @@
 #!/usr/bin/perl
 
 my $x = 1 + (10 / 12) + 15;
-my $x = 3 + (10 / 12) + 17;
+my $y = 3 + (10 / 12) + 17;
